@@ -590,16 +590,8 @@ get_cached_plan(PLpgSQL_checkstate *cstate, PLpgSQL_expr *expr, bool *has_result
 
 	*has_result_desc = plansource->resultDesc ? true : false;
 
-#if PG_VERSION_NUM >= 140000
-
 	cplan = GetCachedPlan(plansource, NULL, NULL, NULL);
 
-#else
-
-	cplan = GetCachedPlan(plansource, NULL, true, NULL);
-
-#endif
-
 	return cplan;
 }
 
@@ -1245,7 +1237,8 @@ plpgsql_check_expr_as_rvalue(PLpgSQL_checkstate *cstate, PLpgSQL_expr *expr,
 
 			if (stmt &&
 				(stmt->cmd_type == PLPGSQL_STMT_EXECSQL ||
-				 stmt->cmd_type == PLPGSQL_STMT_DYNEXECUTE))
+				 stmt->cmd_type == PLPGSQL_STMT_DYNEXECUTE ||
+				 stmt->cmd_type == PLPGSQL_STMT_CALL))
 			{
 				expand = false;
 			}
