@@ -36,7 +36,7 @@ is_internal(char *refname, int lineno)
 }
 
 bool
-is_internal_variable(PLpgSQL_checkstate *cstate, PLpgSQL_variable *var)
+plpgsql_check_is_internal_variable(PLpgSQL_checkstate *cstate, PLpgSQL_variable *var)
 {
 	if (bms_is_member(var->dno, cstate->auto_variables))
 		return true;
@@ -77,15 +77,15 @@ plpgsql_check_datum_get_refname(PLpgSQL_checkstate *cstate, PLpgSQL_datum *d)
 	}
 
 	/*
-	 * This routine is used for shadowing check.
-	 * We would to check auto variables too
+	 * This routine is used for shadowing check. We would to check auto
+	 * variables too
 	 */
 	if (bms_is_member(d->dno, cstate->auto_variables))
 		return refname;
 
 	/*
-	 * PostgreSQL 12 started use "(unnamed row)" name for internal
-	 * variables. Hide this name too (lineno is -1).
+	 * PostgreSQL 12 started use "(unnamed row)" name for internal variables.
+	 * Hide this name too (lineno is -1).
 	 */
 	if (is_internal(refname, lineno))
 		return NULL;
@@ -97,7 +97,7 @@ plpgsql_check_datum_get_refname(PLpgSQL_checkstate *cstate, PLpgSQL_datum *d)
  * Returns true if dno is explicitly declared. It should not be used
  * for arguments.
  */
-bool
+static bool
 datum_is_explicit(PLpgSQL_checkstate *cstate, int dno)
 {
 	PLpgSQL_execstate *estate = cstate->estate;
@@ -110,17 +110,20 @@ datum_is_explicit(PLpgSQL_checkstate *cstate, int dno)
 		case PLPGSQL_DTYPE_VAR:
 			{
 				PLpgSQL_variable *var = (PLpgSQL_variable *) estate->datums[dno];
+
 				return !is_internal(var->refname, var->lineno);
 			}
 
 		case PLPGSQL_DTYPE_ROW:
 			{
 				PLpgSQL_row *row = (PLpgSQL_row *) estate->datums[dno];
+
 				return !is_internal(row->refname, row->lineno);
 			}
 		case PLPGSQL_DTYPE_REC:
 			{
 				PLpgSQL_rec *rec = (PLpgSQL_rec *) estate->datums[dno];
+
 				return !is_internal(rec->refname, rec->lineno);
 			}
 
@@ -142,17 +145,17 @@ datum_is_used(PLpgSQL_checkstate *cstate, int dno, bool write)
 		case PLPGSQL_DTYPE_VAR:
 			{
 				return bms_is_member(dno,
-						write ? cstate->modif_variables : cstate->used_variables);
+									 write ? cstate->modif_variables : cstate->used_variables);
 			}
 			break;
 
 		case PLPGSQL_DTYPE_ROW:
 			{
 				PLpgSQL_row *row = (PLpgSQL_row *) estate->datums[dno];
-				int	     i;
+				int			i;
 
 				if (bms_is_member(dno,
-						  write ? cstate->modif_variables : cstate->used_variables))
+								  write ? cstate->modif_variables : cstate->used_variables))
 					return true;
 
 				for (i = 0; i < row->nfields; i++)
@@ -171,10 +174,10 @@ datum_is_used(PLpgSQL_checkstate *cstate, int dno, bool write)
 		case PLPGSQL_DTYPE_REC:
 			{
 				PLpgSQL_rec *rec = (PLpgSQL_rec *) estate->datums[dno];
-				int	     i;
+				int			i;
 
 				if (bms_is_member(dno,
-						  write ? cstate->modif_variables : cstate->used_variables))
+								  write ? cstate->modif_variables : cstate->used_variables))
 					return true;
 
 				/* search any used recfield with related recparentno */
@@ -185,7 +188,7 @@ datum_is_used(PLpgSQL_checkstate *cstate, int dno, bool write)
 						PLpgSQL_recfield *recfield = (PLpgSQL_recfield *) estate->datums[i];
 
 						if (recfield->recparentno == rec->dno
-								    && datum_is_used(cstate, i, write))
+							&& datum_is_used(cstate, i, write))
 							return true;
 					}
 				}
@@ -194,7 +197,7 @@ datum_is_used(PLpgSQL_checkstate *cstate, int dno, bool write)
 
 		case PLPGSQL_DTYPE_RECFIELD:
 			return bms_is_member(dno,
-					write ? cstate->modif_variables : cstate->used_variables);
+								 write ? cstate->modif_variables : cstate->used_variables);
 
 		default:
 			return false;
@@ -210,7 +213,7 @@ datum_is_used(PLpgSQL_checkstate *cstate, int dno, bool write)
 void
 plpgsql_check_report_unused_variables(PLpgSQL_checkstate *cstate)
 {
-	int i;
+	int			i;
 	PLpgSQL_execstate *estate = cstate->estate;
 
 	/* now, there are no active plpgsql statement */
@@ -227,12 +230,12 @@ plpgsql_check_report_unused_variables(PLpgSQL_checkstate *cstate)
 
 			appendStringInfo(&message, UNUSED_VARIABLE_TEXT, var->refname);
 			plpgsql_check_put_error(cstate,
-					  0, var->lineno,
-					  message.data,
-					  NULL,
-					  NULL,
-					  PLPGSQL_CHECK_WARNING_OTHERS,
-					  0, NULL, NULL);
+									0, var->lineno,
+									message.data,
+									NULL,
+									NULL,
+									PLPGSQL_CHECK_WARNING_OTHERS,
+									0, NULL, NULL);
 
 			pfree(message.data);
 			message.data = NULL;
@@ -246,7 +249,7 @@ plpgsql_check_report_unused_variables(PLpgSQL_checkstate *cstate)
 		for (i = 0; i < estate->ndatums; i++)
 		{
 			if (datum_is_explicit(cstate, i)
-				 && !datum_is_used(cstate, i, false) && datum_is_used(cstate, i, true))
+				&& !datum_is_used(cstate, i, false) && datum_is_used(cstate, i, true))
 			{
 				PLpgSQL_variable *var = (PLpgSQL_variable *) estate->datums[i];
 				StringInfoData message;
@@ -255,12 +258,12 @@ plpgsql_check_report_unused_variables(PLpgSQL_checkstate *cstate)
 
 				appendStringInfo(&message, NEVER_READ_VARIABLE_TEXT, var->refname);
 				plpgsql_check_put_error(cstate,
-						  0, var->lineno,
-						  message.data,
-						  NULL,
-						  NULL,
-						  PLPGSQL_CHECK_WARNING_EXTRA,
-						  0, NULL, NULL);
+										0, var->lineno,
+										message.data,
+										NULL,
+										NULL,
+										PLPGSQL_CHECK_WARNING_EXTRA,
+										0, NULL, NULL);
 
 				pfree(message.data);
 				message.data = NULL;
@@ -270,10 +273,10 @@ plpgsql_check_report_unused_variables(PLpgSQL_checkstate *cstate)
 		/* check IN parameters */
 		for (i = 0; i < func->fn_nargs; i++)
 		{
-			int		varno = func->fn_argvarnos[i];
+			int			varno = func->fn_argvarnos[i];
 
-			bool	is_read = datum_is_used(cstate, varno, false);
-			bool	is_write = datum_is_used(cstate, varno, true);
+			bool		is_read = datum_is_used(cstate, varno, false);
+			bool		is_write = datum_is_used(cstate, varno, true);
 
 			if (!is_read && !is_write)
 			{
@@ -284,26 +287,26 @@ plpgsql_check_report_unused_variables(PLpgSQL_checkstate *cstate)
 
 				appendStringInfo(&message, UNUSED_PARAMETER_TEXT, var->refname);
 				plpgsql_check_put_error(cstate,
-						  0, 0,
-						  message.data,
-						  NULL,
-						  NULL,
-						  PLPGSQL_CHECK_WARNING_EXTRA,
-						  0, NULL, NULL);
+										0, 0,
+										message.data,
+										NULL,
+										NULL,
+										PLPGSQL_CHECK_WARNING_EXTRA,
+										0, NULL, NULL);
 
 				pfree(message.data);
 				message.data = NULL;
 			}
 			else if (!is_read)
 			{
-				bool	is_inout_procedure_param = false;
+				bool		is_inout_procedure_param = false;
 
 				/*
 				 * procedure doesn't support only OUT parameters. Don't raise
 				 * warning if INOUT parameter is just modified in procedures.
 				 */
 				is_inout_procedure_param = cstate->cinfo->is_procedure
-											&& bms_is_member(varno, cstate->out_variables);
+					&& bms_is_member(varno, cstate->out_variables);
 
 				if (!is_inout_procedure_param)
 				{
@@ -314,12 +317,12 @@ plpgsql_check_report_unused_variables(PLpgSQL_checkstate *cstate)
 
 					appendStringInfo(&message, NEVER_READ_PARAMETER_TEXT, var->refname);
 					plpgsql_check_put_error(cstate,
-							  0, 0,
-							  message.data,
-							  NULL,
-							  NULL,
-							  PLPGSQL_CHECK_WARNING_EXTRA,
-							  0, NULL, NULL);
+											0, 0,
+											message.data,
+											NULL,
+											NULL,
+											PLPGSQL_CHECK_WARNING_EXTRA,
+											0, NULL, NULL);
 
 					pfree(message.data);
 					message.data = NULL;
@@ -330,41 +333,41 @@ plpgsql_check_report_unused_variables(PLpgSQL_checkstate *cstate)
 		/* are there some OUT parameters (expect modification)? */
 		if (func->out_param_varno != -1 && !cstate->found_return_query)
 		{
-			int		varno = func->out_param_varno;
+			int			varno = func->out_param_varno;
 			PLpgSQL_variable *var = (PLpgSQL_variable *) estate->datums[varno];
 
-			if (var->dtype == PLPGSQL_DTYPE_ROW && is_internal_variable(cstate, var))
+			if (var->dtype == PLPGSQL_DTYPE_ROW && plpgsql_check_is_internal_variable(cstate, var))
 			{
 				/* this function has more OUT parameters */
-				PLpgSQL_row *row = (PLpgSQL_row*) var;
-				int		fnum;
+				PLpgSQL_row *row = (PLpgSQL_row *) var;
+				int			fnum;
 
 				for (fnum = 0; fnum < row->nfields; fnum++)
 				{
-					int		varno2 = row->varnos[fnum];
+					int			varno2 = row->varnos[fnum];
 					PLpgSQL_variable *var2 = (PLpgSQL_variable *) estate->datums[varno2];
 					StringInfoData message;
 
 					if (var2->dtype == PLPGSQL_DTYPE_ROW ||
-						  var2->dtype == PLPGSQL_DTYPE_REC)
+						var2->dtype == PLPGSQL_DTYPE_REC)
 					{
 						/*
-						 * The result of function with more OUT variables (and one
-						 * should be an composite), is not possible simply assign to
-						 * outer variables. The related expression cannot be "simple"
-						 * expression, and then an evaluation is 10x slower. So there
-						 * is warning 
+						 * The result of function with more OUT variables (and
+						 * one should be an composite), is not possible simply
+						 * assign to outer variables. The related expression
+						 * cannot be "simple" expression, and then an
+						 * evaluation is 10x slower. So there is warning
 						 */
 						initStringInfo(&message);
 						appendStringInfo(&message,
-									  OUT_COMPOSITE_IS_NOT_SINGLE_TEXT, var2->refname);
+										 OUT_COMPOSITE_IS_NOT_SINGLE_TEXT, var2->refname);
 						plpgsql_check_put_error(cstate,
-								  0, 0,
-								  message.data,
-								  NULL,
-								  NULL,
-								  PLPGSQL_CHECK_WARNING_EXTRA,
-								  0, NULL, NULL);
+												0, 0,
+												message.data,
+												NULL,
+												NULL,
+												PLPGSQL_CHECK_WARNING_EXTRA,
+												0, NULL, NULL);
 
 						pfree(message.data);
 						message.data = NULL;
@@ -373,20 +376,20 @@ plpgsql_check_report_unused_variables(PLpgSQL_checkstate *cstate)
 					if (!datum_is_used(cstate, varno2, true))
 					{
 						const char *fmt = cstate->found_return_dyn_query ?
-								  MAYBE_UNMODIFIED_VARIABLE_TEXT : UNMODIFIED_VARIABLE_TEXT;
+							MAYBE_UNMODIFIED_VARIABLE_TEXT : UNMODIFIED_VARIABLE_TEXT;
 
 						const char *detail = cstate->found_return_dyn_query ?
-								  "cannot to determine result of dynamic SQL" : NULL;
+							"cannot to determine result of dynamic SQL" : NULL;
 
 						initStringInfo(&message);
 						appendStringInfo(&message, fmt, var2->refname);
 						plpgsql_check_put_error(cstate,
-								  0, 0,
-								  message.data,
-								  detail,
-								  NULL,
-								  PLPGSQL_CHECK_WARNING_EXTRA,
-								  0, NULL, NULL);
+												0, 0,
+												message.data,
+												detail,
+												NULL,
+												PLPGSQL_CHECK_WARNING_EXTRA,
+												0, NULL, NULL);
 
 						pfree(message.data);
 						message.data = NULL;
@@ -400,21 +403,21 @@ plpgsql_check_report_unused_variables(PLpgSQL_checkstate *cstate)
 					StringInfoData message;
 
 					const char *fmt = cstate->found_return_dyn_query ?
-							  MAYBE_UNMODIFIED_VARIABLE_TEXT : UNMODIFIED_VARIABLE_TEXT;
+						MAYBE_UNMODIFIED_VARIABLE_TEXT : UNMODIFIED_VARIABLE_TEXT;
 
 					const char *detail = cstate->found_return_dyn_query ?
-							  "cannot to determine result of dynamic SQL" : NULL;
+						"cannot to determine result of dynamic SQL" : NULL;
 
 					initStringInfo(&message);
 
 					appendStringInfo(&message, fmt, var->refname);
 					plpgsql_check_put_error(cstate,
-							  0, 0,
-							  message.data,
-							  detail,
-							  NULL,
-							  PLPGSQL_CHECK_WARNING_EXTRA,
-							  0, NULL, NULL);
+											0, 0,
+											message.data,
+											detail,
+											NULL,
+											PLPGSQL_CHECK_WARNING_EXTRA,
+											0, NULL, NULL);
 
 					pfree(message.data);
 					message.data = NULL;
@@ -435,19 +438,19 @@ plpgsql_check_report_too_high_volatility(PLpgSQL_checkstate *cstate)
 	{
 		char	   *current = NULL;
 		char	   *should_be = NULL;
-		bool 		raise_warning = false;
+		bool		raise_warning = false;
 
 		if (cstate->volatility == PROVOLATILE_IMMUTABLE &&
-				(cstate->decl_volatility == PROVOLATILE_VOLATILE ||
-				 cstate->decl_volatility == PROVOLATILE_STABLE))
+			(cstate->decl_volatility == PROVOLATILE_VOLATILE ||
+			 cstate->decl_volatility == PROVOLATILE_STABLE))
 		{
 			should_be = "IMMUTABLE";
 			current = cstate->decl_volatility == PROVOLATILE_VOLATILE ?
-						"VOLATILE" : "STABLE";
+				"VOLATILE" : "STABLE";
 			raise_warning = true;
 		}
 		else if (cstate->volatility == PROVOLATILE_STABLE &&
-				(cstate->decl_volatility == PROVOLATILE_VOLATILE))
+				 (cstate->decl_volatility == PROVOLATILE_VOLATILE))
 		{
 			if (cstate->cinfo->rettype != VOIDOID)
 			{
@@ -465,12 +468,12 @@ plpgsql_check_report_too_high_volatility(PLpgSQL_checkstate *cstate)
 
 			appendStringInfo(&message, "routine is marked as %s, should be %s", current, should_be);
 			plpgsql_check_put_error(cstate,
-					  0, -1,
-					  message.data,
-					  cstate->has_execute_stmt ? "attention: cannot to determine volatility of used dynamic SQL" : NULL,
-					  "When you fix this issue, please, recheck other functions that uses this function.",
-					  PLPGSQL_CHECK_WARNING_PERFORMANCE,
-					  0, NULL, NULL);
+									0, -1,
+									message.data,
+									cstate->has_execute_stmt ? "attention: cannot to determine volatility of used dynamic SQL" : NULL,
+									"When you fix this issue, please, recheck other functions that uses this function.",
+									PLPGSQL_CHECK_WARNING_PERFORMANCE,
+									0, NULL, NULL);
 
 			pfree(message.data);
 			message.data = NULL;
